==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Autoscaling/V2/MetricValueStatus.pm <==
package IO::K8s::Api::Autoscaling::V2::MetricValueStatus;
# ABSTRACT: MetricValueStatus holds the current value for a metric
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s averageUtilization => Int;


k8s averageValue => Str;


k8s value => Str;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Autoscaling::V2::MetricValueStatus - MetricValueStatus holds the current value for a metric

=head1 VERSION

version 1.000

=head2 averageUtilization

currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.

=head2 averageValue

averageValue is the current value of the average of the metric across all relevant pods (as a quantity)

=head2 value

value is the current value of the metric (as a quantity).

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Autoscaling/V2/MetricValueStatus.pm <==
package IO::K8s::Api::Autoscaling::V2::MetricValueStatus;
# ABSTRACT: MetricValueStatus holds the current value for a metric
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s averageUtilization => Int;


k8s averageValue => Str;


k8s value => Str;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Autoscaling::V2::MetricValueStatus - MetricValueStatus holds the current value for a metric

=head1 VERSION

version 1.001

=head2 averageUtilization

currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.

=head2 averageValue

averageValue is the current value of the average of the metric across all relevant pods (as a quantity)

=head2 value

value is the current value of the metric (as a quantity).

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
